@@ -1,4 +1,4 @@
-cv.glmnet=function(x,y,weights,offset=NULL,lambda=NULL,type.measure=c("mse","deviance","class","auc","mae"),nfolds=10,foldid,grouped=TRUE,keep=FALSE,...){
+cv.glmnet=function(x,y,weights,offset=NULL,lambda=NULL,type.measure=c("mse","deviance","class","auc","mae"),nfolds=10,foldid,grouped=TRUE,keep=FALSE,parallel=FALSE,...){
   if(missing(type.measure))type.measure="default"
   else type.measure=match.arg(type.measure)
   if(!is.null(lambda)&&length(lambda)<2)stop("Need more than one value of lambda for cv.glmnet")
@@ -26,12 +26,23 @@ cv.glmnet=function(x,y,weights,offset=NULL,lambda=NULL,type.measure=c("mse","dev
   if(nfolds<3)stop("nfolds must be bigger than 3; nfolds=10 recommended")
    outlist=as.list(seq(nfolds))
 ###Now fit the nfold models and store them
-  for(i in seq(nfolds)){
-    which=foldid==i
-    if(is.matrix(y))y_sub=y[!which,]else y_sub=y[!which]
-    if(is.offset)offset_sub=as.matrix(offset)[!which,]
-    else offset_sub=NULL
-    outlist[[i]]=glmnet(x[!which,,drop=FALSE],y_sub,lambda=lambda,offset=offset_sub,weights=weights[!which],...)
+###First try and do it using foreach if parallel is TRUE
+  if (parallel && require(foreach)) {
+    outlist = foreach (i=seq(nfolds), .packages=c("glmnet")) %dopar% {
+      which=foldid==i
+      if(is.matrix(y))y_sub=y[!which,]else y_sub=y[!which]
+      if(is.offset)offset_sub=as.matrix(offset)[!which,]
+      else offset_sub=NULL
+      glmnet(x[!which,,drop=FALSE],y_sub,lambda=lambda,offset=offset_sub,weights=weights[!which],...)
+    }
+  }else{
+    for(i in seq(nfolds)){
+      which=foldid==i
+      if(is.matrix(y))y_sub=y[!which,]else y_sub=y[!which]
+      if(is.offset)offset_sub=as.matrix(offset)[!which,]
+      else offset_sub=NULL
+      outlist[[i]]=glmnet(x[!which,,drop=FALSE],y_sub,lambda=lambda,offset=offset_sub,weights=weights[!which],...)
+    }
   }
   ###What to do depends on the type.measure and the model fit
   fun=paste("cv",class(glmnet.object)[[1]],sep=".")
